Server

Struct Server 

pub struct Server(pub GenericServer<TcpListener>);
A non-blocking HTTP server powered by Tokio.

Tuple Fields

0: GenericServer<TcpListener>

Implementations

Source

impl Server

pub async fn new( serving_url: &str, routes_list: Option<HashMap<(RequestType, String), RequestHandler>>, ) -> Result<Server, Error>

Creates a new server and binds to the specified URL.

pub fn local_addr(&self) -> Result<SocketAddr, Error>

Returns the socket address the server is currently bound to.

pub fn url(&self) -> &str

pub fn set_cors(&mut self, policy: CorsPolicy)

pub fn set_cors_str(&mut self, config: &str)

pub async fn run(&self)

Starts the server and begins accepting connections.

Methods from Deref<Target = GenericServer<TcpListener>>

pub fn set_auto_close(&mut self, active: bool)

Toggles the Connection: close header.

pub fn add_route( &mut self, path: &str, rt: RequestType, handler: Arc<dyn Handler>, )

Adds a new route to the server.

pub fn url(&self) -> &str

pub fn add_files_source<S>(&mut self, base: S)
where S: Into<String>,

Adds a new directory to serve static files from.