handler

Macro handler 

macro_rules! handler {
    ($handler_fn:expr) => { ... };
}
Simplifies handler creation for asynchronous builds.

This macro expands to a call to the async_h helper function, wrapping the user’s async fn in a closure that pins and boxes the future. This hides the necessary boilerplate from the user, providing a clean API.